<?php

namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\DashboardService;
use FM\Traits\TResponse;

class DashboardController extends FMCrud
{
    use TResponse;
    protected $DashboardService;

    public function __construct($crudService, $environment, DashboardService $DashboardService)
    {
        parent::__construct($crudService, $environment);
        $this->DashboardService = $DashboardService;
    }

    public function getDadosLimpezaFinalizada()
    {
        try {
            $data = $this->DashboardService->getDadosLimpezaFinalizada();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosTarefaAtrasada()
    {
        try {
            $data = $this->DashboardService->getDadosTarefaAtrasada();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosTarefaConcluida()
    {
        try {
            $data = $this->DashboardService->getDadosTarefaConcluida();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosProgress(DTO\Response $response)
    {
        try {
            $dadosProgress = $this->DashboardService->getDadosProgress();
            $dtsVal = new DataSet('dados', $dadosProgress);
            $response->addDataSet($dtsVal);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // ----- Dashboard Supervisor
    public function getDadosUltimasTarefas()
    {
        try {
            $data = $this->DashboardService->getDadosUltimasTarefas();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosResumoTarefas()
    {
        try {
            $data = $this->DashboardService->getDadosResumoTarefas();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findLocal()
    {
        try {
            $data = $this->DashboardService->findLocal();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosChartTarefas()
    {
        try {
            $data = $this->DashboardService->getDadosChartTarefas();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosChartNaoConformidades()
    {

        try {
            $data = $this->DashboardService->getDadosChartNaoConformidades();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosChartProgressoMensal()
    {

        try {
            $data = $this->DashboardService->getDadosChartProgressoMensal();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
