<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class RelatoriosVistoriaFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getRelatoriosVistoria($operadores, $params)
    {

        $session = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI'";
        $this->connection->executeStatement($session);

        $sql = "SELECT GCHK.NRGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.NRCHECKLIST, GCHK.CDOPERADOR, GCHK.IDATIVO, GCHK.NMGERENCIAMENTOCHK, 
                        GCHK.DTHORAAGEND, GCHK.DTHRFINALAGEND, GCHK.NRCHECKLISTAGEND, F.NMOPERADOR, LC.NMLOCALCLIENTE, LC.CDCLIENTE, CHK.NMCHECKLIST, C.NMRAZSOCCLIE, 
                        ROUND(24 *(60 *(GCHK.DTHRFINALAGEND - GCHK.DTHORAAGEND)), 2) || ' min' AS DURACAO,  CHKA.IDSITUACAOAGEND,
                        DECODE(CHKA.IDSITUACAOAGEND, '4', CASE GCHK.IDSITUACAOGERCHK 
                                        WHEN '1' THEN 'Aguardando Vistoria'
                                        WHEN '2' THEN 'Em andamento'
                                        WHEN '3' THEN 'Avaliado'
                                        WHEN '4' THEN 'Cancelado'
                                        ELSE NULL END, 'Tarefa Pendente') AS NMIDSITUACAOGERCHK ,
                        DECODE(CHKA.IDSITUACAOAGEND, '4', CASE GCHK.IDSITUACAOGERCHK 
                                        WHEN '1' THEN '1'
                                        WHEN '2' THEN '2'
                                        WHEN '3' THEN '3'
                                        WHEN '4' THEN '4'
                                        ELSE NULL END, '0') AS IDSITUACAOGERCHK                
                            FROM FCM_GERENCIAMENTOCHK GCHK
                        LEFT JOIN OPERADOR F
                            ON F.CDOPERADOR = GCHK.CDOPERADOR
                        LEFT JOIN FCM_LOCALCLI LC
                            ON LC.NRLOCALCLIENTE = GCHK.NRLOCALCLIENTE
                        LEFT JOIN FCM_CHECKLIST CHK
                            ON CHK.NRCHECKLIST = GCHK.NRCHECKLIST
                        LEFT JOIN CLIENTE C
                            ON C.CDCLIENTE = LC.CDCLIENTE
                        LEFT JOIN FCM_CHECKLISTAGEND CHKA
                            ON CHKA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND
                            WHERE ((CHKA.CDOPERADOR IN ($operadores))
                            OR (CHKA.CDOPERINCLUSAO = :CDOPERADOR))";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function getCriteriosVistoria($parametros)
    {
        $nrgerenciamentochk = $parametros;

        $sql = "SELECT CG.NRCRITERIOTARGERCHK, CG.IDMARCADO, TG.DSOBSTAREFAGERCHK,A.NMATIVIDADE || ' - ' || CG.NMCRITERIOTARGERCHK  AS NMCRITERIO
                        FROM FCM_CRITERIOTARGERCHK CG
                        JOIN FCM_TAREFAGERCHK TG
                        ON TG.NRTAREFAGERCHK = CG.NRTAREFAGERCHK
                        JOIN FCM_TAREFACHK TCHK
                        ON TCHK.NRTAREFACHK = TG.NRTAREFACHK
                        JOIN FCM_ATIVIDADECHK ACHK
                        ON ACHK.NRATIVIDADECHK = TCHK.NRATIVIDADECHK
                        JOIN FCM_ATIVIDADE A
                        ON A.NRATIVIDADE = ACHK.NRATIVIDADE
                    WHERE TG.NRGERENCIAMENTOCHK = $nrgerenciamentochk";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFotosVistoria($parametros)
    {
        $nrgerenciamentochk = $parametros;

        $sql = "SELECT FGCHK.NRFOTOTAREFAGERCHK, FGCHK.NRTAREFAGERCHK, FGCHK.DSFOTOTAREFAGERCHK
                    FROM FCM_FOTOTAREFAGERCHK FGCHK
                    JOIN FCM_TAREFAGERCHK TGCHK
                      ON TGCHK.NRTAREFAGERCHK = FGCHK.NRTAREFAGERCHK
                    JOIN FCM_GERENCIAMENTOCHK GCHK
                      ON TGCHK.NRGERENCIAMENTOCHK = GCHK.NRGERENCIAMENTOCHK
                   WHERE GCHK.NRGERENCIAMENTOCHK = $nrgerenciamentochk";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFiltroVistoriaLocal($listaLocais)
    {
        $sql = "SELECT NRLOCALCLIENTE, NMLOCALCLIENTE
                  FROM FCM_LOCALCLI 
                  WHERE NRTIPOLOCALCLI IN (SELECT NRTIPOLOCALCLI
                                              FROM FCM_TIPOLOCALCLI
                                          WHERE IDTIPOLOCALCLI = '3') 
                  AND IDATIVO = 'S'
                  AND NRLOCALCLIENTE IN ($listaLocais)";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFiltroVistoriaChecklist()
    {
        $sql = "SELECT NRCHECKLIST, NMCHECKLIST
                  FROM FCM_CHECKLIST
                 WHERE IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFiltroVistoriaCliente()
    {
        $sql = "SELECT CDCLIENTE, NMRAZSOCCLIE 
                  FROM CLIENTE
                  WHERE IDCLIEATIV = 'S'
                      AND IDATIVO = 'S' 
                      AND CDCLIENTE IN (SELECT CDCLIENTE 
                                          FROM FCM_LOCALCLI
                                      WHERE IDATIVO = 'S')";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFiltroVistoriaSituacao()
    {
        $sql = "SELECT DISTINCT DECODE(CHKA.IDSITUACAOAGEND, '4', CASE GCHK.IDSITUACAOGERCHK 
                                        WHEN '1' THEN 'Aguardando Vistoria'
                                        WHEN '2' THEN 'Em andamento'
                                        WHEN '3' THEN 'Avaliado'
                                        WHEN '4' THEN 'Cancelado'
                                        ELSE NULL END, 'Tarefa Pendente') AS NMIDSITUACAOGERCHK ,
                                DECODE(CHKA.IDSITUACAOAGEND, '4', CASE GCHK.IDSITUACAOGERCHK 
                                        WHEN '1' THEN '1'
                                        WHEN '2' THEN '2'
                                        WHEN '3' THEN '3'
                                        WHEN '4' THEN '4'
                                        ELSE NULL END, '0') AS IDSITUACAOGERCHK 
                    FROM FCM_GERENCIAMENTOCHK GCHK
                    LEFT JOIN FCM_CHECKLISTAGEND CHKA
                    ON CHKA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
}
